@@ -137,7 +137,7 @@ JuK::JuK(const QStringList &filesToOpen, QWidget *parent) :
                                        QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
                                        QDBusConnection::sessionBus());
 
-    connect(m_player, &PlayerManager::signalPlay, [=] () {
+    connect(m_player, &PlayerManager::signalPlay, pmInterface, [=] () {
         QDBusReply<uint> reply;
         if (pmInterface->isValid() && (m_pmToken == 0)) {
             reply = pmInterface->call(QStringLiteral("Inhibit"),
@@ -259,7 +259,7 @@ void JuK::setupActions()
     KActionMenu *actionMenu = collection->add<KActionMenu>("actionMenu");
     actionMenu->setText(i18n("&Random Play"));
     actionMenu->setIcon(QIcon::fromTheme( QLatin1String( "media-playlist-shuffle" )));
-    actionMenu->setDelayed(false);
+    actionMenu->setPopupMode(QToolButton::InstantPopup);
 
     QActionGroup* randomPlayGroup = new QActionGroup(this);
 
